@@ -5,10 +5,9 @@
 # as set forth in the License.
 
 
+from steelscript.common.datastructures import DictObject
 
 
-from steelscript.common.utils import DictObject
-
 class ExtractorField(DictObject):
     @classmethod
     def get_all(cls, shark):
